@@ -21,7 +21,7 @@ class LifecycleActionType(models.Model):
 
 class Lifecycle(ChangeLoggedModel):
 	date = models.DateField(default=timezone.now)
-	user = models.ForeignKey(Tenant, on_delete=models.PROTECT)
+	user = models.ForeignKey(Tenant, on_delete=models.PROTECT, blank=True, null=True)
 	device = models.ForeignKey(Device, on_delete=models.PROTECT)
 	action_type = models.ForeignKey(LifecycleActionType, on_delete=models.PROTECT)
 
